# Cognitive COmputation for Behavioral Reasoning Analysis (CCOBRA) Framework

[![](https://img.shields.io/pypi/v/ccobra.svg)](https://pypi.org/pypi/ccobra/)
[![](https://img.shields.io/pypi/pyversions/ccobra.svg)](https://pypi.org/pypi/ccobra/)
[![GitHub license](https://img.shields.io/github/license/CognitiveComputationLab/ccobra.svg)](https://github.com/CognitiveComputationLab/ccobra/blob/master/LICENSE)
[![DOI](https://zenodo.org/badge/144011537.svg)](https://zenodo.org/badge/latestdoi/144011537)

[Documentation](http://orca.informatik.uni-freiburg.de/orca_sylwebsite/orca/documentation/index.html)

## Installation

### PyPi

CCOBRA is available via `pip`. To install the current version, run the following command:

```
$> pip install ccobra
```

to update your installation, run `pip install -U ccobra`.

### Development Version

It is also possible to install a development version of CCOBRA. The difference to the standard version is that changes to the local copy of the repository are directly reflected in the module loaded from Python via `import`. To install the develop version, download a local copy of the repository and run the following commands:

```
$> cd /path/to/repository/
$> python setup.py develop [--user]
```

To remove the development version, run the following commands:

```
$> cd /path/to/repository
$> python setup.py develop [--user] --uninstall
```
